ZSCheckoutConfigExpiredException class
The deferred-mode checkout config expired (the server-side PENDING
transaction's checkout_config_expires_at has passed). Re-initiate
checkout to obtain a fresh session rather than retrying finalize.
- Inheritance
-
- Object
- ZeroSettleException
- ZSCheckoutConfigExpiredException
Constructors
- ZSCheckoutConfigExpiredException(String message)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited