ZSCheckoutNotStartedException class

Checkout could not start (e.g. backend failed to create the payment intent). Distinct from terminal errors that occur after checkout is in flight.

Inheritance

Constructors

ZSCheckoutNotStartedException(String message)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited