ZSUserNotIdentifiedException class

A user-scoped method was called before ZeroSettle.identify. Call ZeroSettle.identify with Identity.user (or Identity.anonymous) at app launch (after ZeroSettle.configure) before invoking user-scoped APIs like ZeroSettle.restoreEntitlements.

Inheritance

Constructors

ZSUserNotIdentifiedException(String message)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited