ZeroSettleException class sealed
Base exception type for the ZeroSettle SDK.
- Implemented types
- Implementers
- ZSApiException
- ZSApplePaySetupRequiredException
- ZSApplePayUnavailableException
- ZSCancelledException
- ZSCheckoutConfigExpiredException
- ZSCheckoutFailedException
- ZSCheckoutNotStartedException
- ZSInvalidPublishableKeyException
- ZSNotConfiguredException
- ZSProductNotFoundException
- ZSPurchasePendingException
- ZSTransactionVerificationFailedException
- ZSUserIdRequiredException
- ZSUserNotIdentifiedException
- ZSWebCheckoutDisabledException
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPlatformException(
PlatformException e) → ZeroSettleException - Maps a PlatformException from the native bridge to a typed ZeroSettleException.