markCheckoutSucceeded method

  1. @Deprecated('Bookkeeping is automatic when you call ZeroSettle.instance.presentPaymentSheet or ZeroSettle.instance.purchase. The body of this method is preserved through 1.x for adopters using `startCheckout` (raw URL escape hatch) who need to call it manually after their out-of-band checkout completes. Will be removed in 2.0.')
Future<void> markCheckoutSucceeded({
  1. String? transactionId,
})

Mark the checkout as succeeded; transitions state toward accepted (when OfferData.needsAppleCancel is true) or completed.

Implementation

@Deprecated('Bookkeeping is automatic when you call ZeroSettle.instance.presentPaymentSheet or ZeroSettle.instance.purchase. The body of this method is preserved through 1.x for adopters using `startCheckout` (raw URL escape hatch) who need to call it manually after their out-of-band checkout completes. Will be removed in 2.0.')
Future<void> markCheckoutSucceeded({String? transactionId}) async {
  _ensureNotDisposed();
  await _methodChannel.invokeMethod<void>('markCheckoutSucceeded', {
    if (transactionId != null) 'transactionId': transactionId,
  });
}