CancelFlowAnswerPayload class

A single answer within a cancel flow response.

Constructors

CancelFlowAnswerPayload({required int questionId, int? selectedOptionId, String? freeText})

Properties

freeText String?
final
hashCode int
The hash code for this object.
no setterinherited
questionId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedOptionId int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited