CancelFlowOffer class
Save offer configuration shown to retain the user.
Constructors
- CancelFlowOffer({required bool enabled, required String title, required String body, required String ctaText, required String type, required String value})
-
CancelFlowOffer.fromMap(Map<
String, dynamic> map) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited