CancelFlowPauseOption class

A single pause duration option in the cancel flow.

Constructors

CancelFlowPauseOption({required int id, required int order, required String label, required String durationType, int? durationDays, DateTime? resumeDate})
CancelFlowPauseOption.fromMap(Map<String, dynamic> map)
factory

Properties

durationDays int?
final
durationType String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
label String
final
order int
final
resumeDate DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited