CancelFlowResponse class

The complete response submitted at the end of a cancel flow.

Constructors

CancelFlowResponse({required String productId, required String userId, required CancelFlowOutcome outcome, required List<CancelFlowAnswer> answers, required bool offerShown, required bool offerAccepted, required bool pauseShown, required bool pauseAccepted, int? pauseDurationDays})

Properties

answers List<CancelFlowAnswer>
final
hashCode int
The hash code for this object.
no setterinherited
offerAccepted bool
final
offerShown bool
final
outcome CancelFlowOutcome
final
pauseAccepted bool
final
pauseDurationDays int?
final
pauseShown bool
final
productId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited