CancelFlowSaveOfferResult class

Result of accepting a save offer.

Constructors

CancelFlowSaveOfferResult({required String message, required int discountPercent, required int durationMonths})
CancelFlowSaveOfferResult.fromMap(Map<String, dynamic> map)
factory

Properties

discountPercent int
final
durationMonths int
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited