ZSTrialMode enum

The trial billing mode for a subscription product.

Inheritance
Available extensions

Values

free → const ZSTrialMode
const ZSTrialMode('free')
const ZSTrialMode('paid')
authHold → const ZSTrialMode
const ZSTrialMode('auth_hold')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromRawValueOrNull(String value) ZSTrialMode?

Constants

values → const List<ZSTrialMode>
A constant List of the values in this enum, in order of their declaration.