FunnelEventType enum

Funnel analytics event types for paywall and checkout tracking.

Inheritance
Available extensions

Values

paywallViewed → const FunnelEventType
const FunnelEventType('paywall_viewed')
checkoutStarted → const FunnelEventType
const FunnelEventType('checkout_started')
checkoutAbandoned → const FunnelEventType
const FunnelEventType('checkout_abandoned')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FunnelEventType>
A constant List of the values in this enum, in order of their declaration.