MigrationOfferState enum
Lifecycle state of the migration offer flow. Mirrors
MigrationOffer.State from ZeroSettleKit.
Values
- loading → const MigrationOfferState
-
const MigrationOfferState('loading') - ineligible → const MigrationOfferState
-
const MigrationOfferState('ineligible') - eligible → const MigrationOfferState
-
const MigrationOfferState('eligible') - presented → const MigrationOfferState
-
const MigrationOfferState('presented') - accepted → const MigrationOfferState
-
const MigrationOfferState('accepted') - completed → const MigrationOfferState
-
const MigrationOfferState('completed') - dismissed → const MigrationOfferState
-
const MigrationOfferState('dismissed')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - rawValue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromRawValue(
String value) → MigrationOfferState
Constants
-
values
→ const List<
MigrationOfferState> - A constant List of the values in this enum, in order of their declaration.