OfferCheckoutPresentation enum

How the tip view presents checkout when the CTA is tapped. Mirrors Offer.CheckoutPresentation. When null, the SDK uses the global checkoutType setting.

Inheritance
Available extensions

Values

inline → const OfferCheckoutPresentation

Expand checkout inline within the tip card.

const OfferCheckoutPresentation('inline')
sheet → const OfferCheckoutPresentation

Present the bottom checkout sheet overlay.

const OfferCheckoutPresentation('sheet')
safariVC → const OfferCheckoutPresentation

Open an in-app browser (SFSafariViewController).

const OfferCheckoutPresentation('safari_vc')
safari → const OfferCheckoutPresentation

Open external Safari.

const OfferCheckoutPresentation('safari')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromRawValue(String value) OfferCheckoutPresentation

Constants

values → const List<OfferCheckoutPresentation>
A constant List of the values in this enum, in order of their declaration.