OfferDisplay class

Server-configurable display copy for every tip-card state. Empty strings mean "use SDK default". Mirrors Offer.Display.

Constructors

OfferDisplay({required String offerTitle, required String offerMessage, required String offerCta, required String acceptedTitle, required String acceptedMessage, required String acceptedCta, required String completedTitle, required String completedMessage})
const
OfferDisplay.fromMap(Map<String, dynamic> map)
factory

Properties

acceptedCta String
final
acceptedMessage String
final
acceptedTitle String
final
completedMessage String
final
completedTitle String
final
hashCode int
The hash code for this object.
no setteroverride
offerCta String
final
offerMessage String
final
offerTitle String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override