OfferManagerState class

Coherent snapshot of ZSOfferManager's 5 published properties. Emitted on every state-property change via the manager's stream.

Constructors

OfferManagerState({required OfferState state, OfferOfferData? offerData, String? checkoutErrorMessage, required bool isLoading, required bool storekitCancelRequired})
const
OfferManagerState.fromMap(Map<String, dynamic> map)
factory

Properties

checkoutErrorMessage String?
final
hashCode int
The hash code for this object.
no setteroverride
isLoading bool
final
offerData OfferOfferData?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state OfferState
final
storekitCancelRequired bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override