OfferPerProductOffer class

Per-product offer override. Mirrors Offer.PerProductOffer.

Constructors

OfferPerProductOffer({required String productId, required int savingsPercent, required OfferDisplay display})
const
OfferPerProductOffer.fromMap(Map<String, dynamic> map)
factory

Properties

display OfferDisplay
final
hashCode int
The hash code for this object.
no setteroverride
productId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savingsPercent int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override