OfferState enum
Lifecycle state of the offer flow. Mirrors Offer.State.
Values
- loading → const OfferState
-
const OfferState('loading') - ineligible → const OfferState
-
const OfferState('ineligible') - eligible → const OfferState
-
const OfferState('eligible') - presented → const OfferState
-
const OfferState('presented') - accepted → const OfferState
-
const OfferState('accepted') - completed → const OfferState
-
const OfferState('completed') - dismissed → const OfferState
-
const OfferState('dismissed')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - rawValue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromRawValue(
String value) → OfferState
Constants
-
values
→ const List<
OfferState> - A constant List of the values in this enum, in order of their declaration.