OfferUpgradeType enum

The upgrade-path type (only relevant for upgrade flows). Mirrors Offer.UpgradeType.

Inheritance
Available extensions

Values

storekitToWeb → const OfferUpgradeType
const OfferUpgradeType('storekit_to_web')
webToWeb → const OfferUpgradeType
const OfferUpgradeType('web_to_web')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromRawValue(String value) OfferUpgradeType

Constants

values → const List<OfferUpgradeType>
A constant List of the values in this enum, in order of their declaration.