toMap abstract method

Map<String, dynamic> toMap()

Round-trips the action back to a channel map (used by widgets that pass an action to a native PlatformView).

Implementation

Map<String, dynamic> toMap();