UpgradeOfferConfig class
Upgrade offer configuration returned by the backend.
Constructors
- UpgradeOfferConfig({required bool available, String? reason, UpgradeOfferCurrentProduct? currentProduct, UpgradeOfferTargetProduct? targetProduct, int? savingsPercent, String? upgradeType, UpgradeOfferProration? proration, UpgradeOfferDisplay? display, int? variantId})
-
UpgradeOfferConfig.fromMap(Map<
String, dynamic> map) -
factory
Properties
- available → bool
-
final
- currentProduct → UpgradeOfferCurrentProduct?
-
final
- display → UpgradeOfferDisplay?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- proration → UpgradeOfferProration?
-
final
- reason → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savingsPercent → int?
-
final
- targetProduct → UpgradeOfferTargetProduct?
-
final
- upgradeType → String?
-
final
- variantId → int?
-
A/B experiment variant identifier, if this config is part of an experiment.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited