UpgradeOfferDisplay class
Display copy for the upgrade offer sheet.
Constructors
- UpgradeOfferDisplay({required String title, required String body, required String ctaText, required String dismissText, String? storekitMigrationBody, String? cancelInstructions})
-
UpgradeOfferDisplay.fromMap(Map<
String, dynamic> map) -
factory
Properties
- body → String
-
final
- cancelInstructions → String?
-
final
- ctaText → String
-
final
- dismissText → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storekitMigrationBody → String?
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited