UpgradeOfferProration class
Proration details for the upgrade transition.
Constructors
- UpgradeOfferProration({required int prorationAmountCents, required String currency, int? nextBillingDate})
-
UpgradeOfferProration.fromMap(Map<
String, dynamic> map) -
factory
Properties
- currency → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextBillingDate → int?
-
final
- prorationAmountCents → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited