UpgradeOfferResponsePayload class

Payload submitted to the backend after an upgrade offer completes.

Constructors

UpgradeOfferResponsePayload({required String userId, required String currentProductId, required String targetProductId, required String outcome, required String upgradeType, int? variantId})

Properties

currentProductId String
final
hashCode int
The hash code for this object.
no setterinherited
outcome String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetProductId String
final
upgradeType String
final
userId String
final
variantId int?
A/B experiment variant identifier echoed back from the config.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited