checkoutProductId property
Product ID to open in the checkout sheet when the CTA is tapped.
null when actionType is UserOfferActionType.noAction.
Implementation
final String? checkoutProductId;
Product ID to open in the checkout sheet when the CTA is tapped.
null when actionType is UserOfferActionType.noAction.
final String? checkoutProductId;