requiresAppleCancel property
Whether the SDK must prompt the user to cancel their Apple subscription after checkout completes.
Implementation
final bool requiresAppleCancel;
Whether the SDK must prompt the user to cancel their Apple subscription after checkout completes.
final bool requiresAppleCancel;