source property
The storefront from which the user's active subscription originates.
null for web-originated subscriptions or when there is no active sub.
Implementation
final UserOfferSourceStorefront? source;
The storefront from which the user's active subscription originates.
null for web-originated subscriptions or when there is no active sub.
final UserOfferSourceStorefront? source;