UserOfferProration class

Proration details for a web→web or storeKit→web subscription upgrade.

Mirrors UserOffer.Proration on Android.

Constructors

UserOfferProration({required int amountCents, required String currency, String? nextBillingDate})
const
UserOfferProration.fromMap(Map<String, dynamic> m)
factory

Properties

amountCents int
The credit amount in the smallest currency unit (e.g. cents for USD).
final
currency String
ISO 4217 currency code (e.g. "usd").
final
hashCode int
The hash code for this object.
no setterinherited
nextBillingDate String?
ISO 8601 date string for the next billing date after the plan switch. null when the backend does not supply a date.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited