nextBillingDate property
ISO 8601 date string for the next billing date after the plan switch.
null when the backend does not supply a date.
Implementation
final String? nextBillingDate;
ISO 8601 date string for the next billing date after the plan switch.
null when the backend does not supply a date.
final String? nextBillingDate;