UserOfferSourceStorefront enum

The storefront the user's current active subscription originates from.

Mirrors UserOffer.SourceStorefront on Android.

Inheritance
Available extensions

Values

storeKit → const UserOfferSourceStorefront

Apple App Store / StoreKit.

playStore → const UserOfferSourceStorefront

Google Play Store.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWire(String? s) UserOfferSourceStorefront?
Decode a camelCase wire string. Returns null on null or unknown values since the source field is optional (absent on web-originating offers).

Constants

values → const List<UserOfferSourceStorefront>
A constant List of the values in this enum, in order of their declaration.