ZSEventMigrationCompleted class final

Emitted when a Switch & Save migration has completed successfully.

Inheritance

Constructors

ZSEventMigrationCompleted({required String productId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
productId String
The product ID that was migrated to web billing.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited