presentPaymentSheet method

Future<Map<String, dynamic>> presentPaymentSheet({
  1. required String productId,
  2. String? userId,
  3. bool dismissible = true,
})

iOS only. Android intentionally returns a not_implemented error — Android routes payment through Google Play User Choice Billing, and the web payment sheet is presented internally by the SDK for upgrade/switch offers rather than via this method.

Implementation

Future<Map<String, dynamic>> presentPaymentSheet({
  required String productId,
  String? userId,
  bool dismissible = true,
}) {
  throw UnimplementedError('presentPaymentSheet() has not been implemented.');
}