ZSCheckoutNotStartedException class
Checkout could not start (e.g. backend failed to create the payment intent). Distinct from terminal errors that occur after checkout is in flight.
- Inheritance
-
- Object
- ZeroSettleException
- ZSCheckoutNotStartedException
Constructors
- ZSCheckoutNotStartedException(String message)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited