CancelFlowConfig class
Cancel flow configuration returned by the backend.
Constructors
-
CancelFlowConfig({required bool enabled, required List<
CancelFlowQuestion> questions, CancelFlowOffer? offer, CancelFlowPauseConfig? pause, int? variantId}) -
CancelFlowConfig.fromMap(Map<
String, dynamic> map) -
factory
Properties
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offer → CancelFlowOffer?
-
final
- pause → CancelFlowPauseConfig?
-
final
-
questions
→ List<
CancelFlowQuestion> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variantId → int?
-
A/B experiment variant identifier, if this config is part of an experiment.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited