CancelFlowOption class
An answer option for a single-select question.
Constructors
- CancelFlowOption({required int id, required int order, required String label, required bool triggersOffer, required bool triggersPause})
-
CancelFlowOption.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- label → String
-
final
- order → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- triggersOffer → bool
-
final
- triggersPause → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited