CancelFlowQuestion class
A single question in the cancel flow questionnaire.
Constructors
-
CancelFlowQuestion({required int id, required int order, required String questionText, required String questionType, required bool isRequired, required List<
CancelFlowOption> options}) -
CancelFlowQuestion.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- isRequired → bool
-
final
-
options
→ List<
CancelFlowOption> -
final
- order → int
-
final
- questionText → String
-
final
- questionType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited