CancelFlowResponsePayload class
Payload submitted to the backend after a cancel flow completes.
Constructors
-
CancelFlowResponsePayload({required String userId, required String productId, required String outcome, required bool offerShown, required bool offerAccepted, bool pauseShown = false, bool pauseAccepted = false, int? pauseDurationDays, required int lastStepSeen, required List<
CancelFlowAnswerPayload> answers, int? variantId})
Properties
-
answers
→ List<
CancelFlowAnswerPayload> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastStepSeen → int
-
final
- offerAccepted → bool
-
final
- offerShown → bool
-
final
- outcome → String
-
final
- pauseAccepted → bool
-
final
- pauseDurationDays → int?
-
final
- pauseShown → bool
-
final
- productId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
final
- variantId → int?
-
A/B experiment variant identifier echoed back from the config.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited