Entitlement class
Represents an active entitlement from either a StoreKit or web checkout purchase.
Constructors
- Entitlement({required String id, required String productId, required EntitlementSource source, required bool isActive, DateTime? expiresAt, required DateTime purchasedAt, String? status, DateTime? pausedAt, DateTime? pauseResumesAt, bool willRenew = true, bool isTrial = false, DateTime? trialEndsAt, DateTime? cancelledAt, String? storekitOriginalTransactionId, DateTime? originalPurchaseDate})
-
const
-
Entitlement.fromMap(Map<
String, dynamic> map) -
factory
Properties
- cancelledAt → DateTime?
-
final
- expiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- isActive → bool
-
final
- isPaused → bool
-
Whether this entitlement is currently paused.
no setter
- isTrial → bool
-
final
- originalPurchaseDate → DateTime?
-
final
- pausedAt → DateTime?
-
final
- pauseResumesAt → DateTime?
-
final
- productId → String
-
final
- purchasedAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → EntitlementSource
-
final
- status → String?
-
final
- storekitOriginalTransactionId → String?
-
final
- trialEndsAt → DateTime?
-
final
- willRenew → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override