MigrationOfferData class
Server-driven data for an eligible migration offer. Mirrors
MigrationOffer.OfferData from ZeroSettleKit.
Constructors
- MigrationOfferData({required MigrationPrompt prompt, required int freeTrialDays, required String activeStoreKitProductId, DateTime? storekitSubscriptionEnd, String? activeStoreKitOriginalTransactionId})
-
const
-
MigrationOfferData.fromMap(Map<
String, dynamic> map) -
factory
Properties
- activeStoreKitOriginalTransactionId → String?
-
final
- activeStoreKitProductId → String
-
final
- freeTrialDays → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- prompt → MigrationPrompt
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storekitSubscriptionEnd → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override