OfferOfferData class
Server-resolved offer payload. Mirrors Offer.OfferData.
The Dart class name keeps the Offer prefix to mirror Swift's
nested Offer.OfferData namespacing.
Constructors
-
OfferOfferData({required OfferFlowType flowType, required String productId, required List<
String> eligibleProductIds, required int savingsPercent, required OfferDisplay display, required int freeTrialDays, required int minSubscriptionDays, int? maxSubscriptionDays, int? rolloutPercent, OfferUpgradeType? upgradeType, String? fromProductId, String? toProductId, int? variantId, Map<String, OfferPerProductOffer> ? perProductPrompts, OfferCheckoutPresentation? checkoutPresentation}) -
const
-
OfferOfferData.fromMap(Map<
String, dynamic> map) -
factory
Properties
- checkoutPresentation → OfferCheckoutPresentation?
-
final
- checkoutProductId → String
-
The target product ID for checkout (
toProductIdfor upgrades,productIdfor migration). MirrorsOffer.OfferData.checkoutProductId.no setter - display → OfferDisplay
-
final
-
eligibleProductIds
→ List<
String> -
final
- flowType → OfferFlowType
-
final
- freeTrialDays → int
-
final
- fromProductId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxSubscriptionDays → int?
-
final
- minSubscriptionDays → int
-
final
- needsAppleCancel → bool
-
Whether this offer requires Apple subscription cancellation
post-checkout. Mirrors
Offer.OfferData.needsAppleCancel.no setter -
perProductPrompts
→ Map<
String, OfferPerProductOffer> ? -
final
- productId → String
-
final
- rolloutPercent → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savingsPercent → int
-
final
- toProductId → String?
-
final
- upgradeType → OfferUpgradeType?
-
final
- variantId → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override