UpgradeOfferCurrentProduct class
The user's current subscription product within an upgrade offer.
Constructors
- UpgradeOfferCurrentProduct({required String referenceId, required String name, required int priceCents, required String currency, required int durationDays, required String billingLabel})
-
UpgradeOfferCurrentProduct.fromMap(Map<
String, dynamic> map) -
factory
Properties
- billingLabel → String
-
final
- currency → String
-
final
- durationDays → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- priceCents → int
-
final
- referenceId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited