UserOfferAppleSubscription class
Current Apple subscription state for the user's active StoreKit product.
Mirrors UserOffer.AppleSubscription on Android.
Constructors
- UserOfferAppleSubscription({required bool isActive, String? expiresAt, required int statusCode, required bool autoRenewEnabled})
-
const
-
UserOfferAppleSubscription.fromMap(Map<
String, dynamic> m) -
factory
Properties
- autoRenewEnabled → bool
-
Whether auto-renewal is enabled for the subscription.
final
- expiresAt → String?
-
ISO 8601 expiry date string.
nullif not yet known.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Whether the subscription is currently active.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
Raw App Store status code (see Apple's
Statusenum).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited