UserOfferResponse class
Top-level response from fetchUserOffer().
Mirrors UserOfferResponse on Android. The isEligible getter is a
convenience accessor that delegates to offer.isEligible.
Constructors
- UserOfferResponse({required String userId, required String appId, required bool isSandbox, required UserOfferSubscription subscription, required UserOfferData offer, required String serverTime})
-
const
-
UserOfferResponse.fromMap(Map<
String, dynamic> m) -
factory
Properties
- appId → String
-
The app identifier this offer was resolved for.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEligible → bool
-
Whether the user is eligible for the offer. Convenience accessor that
delegates to
offer.isEligible.no setter - isSandbox → bool
-
Whether the offer was resolved in sandbox mode.
final
- offer → UserOfferData
-
The resolved offer data.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverTime → String
-
ISO 8601 server timestamp when the response was generated.
final
- subscription → UserOfferSubscription
-
The user's current subscription summary.
final
- userId → String
-
The ZeroSettle user identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited