UserOfferSubscription class
Summary of the user's current subscription state.
Mirrors UserOffer.Subscription on Android.
Constructors
- UserOfferSubscription({required String type, String? productId})
-
const
-
UserOfferSubscription.fromMap(Map<
String, dynamic> m) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- productId → String?
-
The ZeroSettle product reference ID of the active subscription.
nullwhen type is"none".final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Subscription type descriptor (e.g.
"activeWeb","activeStorekit","none").final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited