CheckoutTransaction class
Represents a completed or pending purchase transaction.
Constructors
- CheckoutTransaction({required String id, required String productId, required TransactionStatus status, required EntitlementSource source, required DateTime purchasedAt, DateTime? expiresAt, String? productName, int? amountCents, String? currency, int? storekitStatus})
-
const
-
CheckoutTransaction.fromMap(Map<
String, dynamic> map) -
factory
Properties
- amountCents → int?
-
final
- currency → String?
-
final
- expiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- productId → String
-
final
- productName → String?
-
final
- purchasedAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → EntitlementSource
-
final
- status → TransactionStatus
-
final
- storekitStatus → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override