MethodChannelZeroSettle class
An implementation of ZeroSettlePlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- ZeroSettlePlatform
- MethodChannelZeroSettle
Constructors
Properties
- checkoutEventChannel → EventChannel
-
final
-
checkoutEvents
→ Stream<
Map< String, dynamic> > -
no setteroverride
- entitlementEventChannel → EventChannel
-
final
-
entitlementUpdates
→ Stream<
List< Map< >String, dynamic> > -
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptSaveOffer(
{required String productId, required String userId}) → Future< Map< String, dynamic> > -
override
-
bootstrap(
{required String userId}) → Future< Map< String, dynamic> > -
override
-
cancelSubscription(
{required String productId, required String userId, bool immediate = false}) → Future< void> -
override
-
configure(
{required String publishableKey, bool syncStoreKitTransactions = true}) → Future< void> -
override
-
fetchCancelFlowConfig(
{String? userId}) → Future< Map< String, dynamic> > -
override
-
fetchProducts(
{String? userId}) → Future< Map< String, dynamic> > -
override
-
fetchTransactionHistory(
{required String userId}) → Future< List< Map< >String, dynamic> > -
override
-
fetchUpgradeOfferConfig(
{String? productId, required String userId}) → Future< Map< String, dynamic> > -
override
-
getCancelFlowConfig(
) → Future< Map< String, dynamic> ?> -
override
-
getDetectedJurisdiction(
) → Future< String?> -
override
-
getEntitlements(
) → Future< List< Map< >String, dynamic> > -
override
-
getIsConfigured(
) → Future< bool> -
override
-
getPendingCheckout(
) → Future< bool> -
override
-
getProducts(
) → Future< List< Map< >String, dynamic> > -
override
-
getRemoteConfig(
) → Future< Map< String, dynamic> ?> -
override
-
handleUniversalLink(
String url) → Future< bool> -
override
-
hasActiveEntitlement(
{required String productId}) → Future< bool> -
override
-
identify(
{required String type, String? id, String? name, String? email}) → Future< Map< String, dynamic> ?> -
override
-
logout(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openCustomerPortal(
{required String userId}) → Future< void> -
override
-
pauseSubscription(
{required String productId, required String userId, required int pauseOptionId}) → Future< String?> -
override
-
preloadPaymentSheet(
{required String productId, String? userId}) → Future< void> -
override
-
presentCancelFlow(
{required String productId, required String userId}) → Future< String> -
inherited
-
presentPaymentSheet(
{required String productId, String? userId, bool dismissible = true}) → Future< Map< String, dynamic> > -
override
-
presentSaveTheSaleSheet(
) → Future< String> -
override
-
presentUpgradeOffer(
{String? productId, required String userId}) → Future< String> -
override
-
product(
{required String productId}) → Future< Map< String, dynamic> ?> -
override
-
resetMigrateTipState(
) → Future< void> -
override
-
restoreEntitlements(
{required String userId}) → Future< List< Map< >String, dynamic> > -
override
-
resumeSubscription(
{required String productId, required String userId}) → Future< void> -
override
-
setBaseUrlOverride(
String? url) → Future< void> -
inherited
-
setCustomer(
{String? name, String? email}) → Future< void> -
override
-
showManageSubscription(
{required String userId}) → Future< void> -
override
-
submitCancelFlowResponse(
Map< String, dynamic> response) → Future<void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
trackEvent(
{required String eventType, required String productId, String? screenName, Map< String, String> ? metadata}) → Future<void> -
override
-
trackMigrationConversion(
{required String userId}) → Future< void> -
override
-
transferStoreKitOwnershipToCurrentUser(
{required String productId}) → Future< void> -
override
-
warmUpPaymentSheet(
{required String productId, String? userId}) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited