ZeroSettlePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ZeroSettlePlatform
Implementers

Constructors

ZeroSettlePlatform()

Properties

checkoutEvents Stream<Map<String, dynamic>>
no setter
entitlementUpdates Stream<List<Map<String, dynamic>>>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptSaveOffer({required String productId, required String userId}) Future<Map<String, dynamic>>
bootstrap({required String userId}) Future<Map<String, dynamic>>
cancelSubscription({required String productId, required String userId, bool immediate = false}) Future<void>
configure({required String publishableKey, bool syncStoreKitTransactions = true}) Future<void>
fetchCancelFlowConfig({String? userId}) Future<Map<String, dynamic>>
fetchProducts({String? userId}) Future<Map<String, dynamic>>
fetchTransactionHistory({required String userId}) Future<List<Map<String, dynamic>>>
fetchUpgradeOfferConfig({String? productId, required String userId}) Future<Map<String, dynamic>>
getCancelFlowConfig() Future<Map<String, dynamic>?>
getDetectedJurisdiction() Future<String?>
getEntitlements() Future<List<Map<String, dynamic>>>
getIsConfigured() Future<bool>
getPendingCheckout() Future<bool>
getProducts() Future<List<Map<String, dynamic>>>
getRemoteConfig() Future<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCustomerPortal({required String userId}) Future<void>
pauseSubscription({required String productId, required String userId, required int pauseOptionId}) Future<String?>
preloadPaymentSheet({required String productId, String? userId}) Future<void>
presentCancelFlow({required String productId, required String userId}) Future<String>
presentPaymentSheet({required String productId, String? userId, bool dismissible = true}) Future<Map<String, dynamic>>
presentSaveTheSaleSheet() Future<String>
presentUpgradeOffer({String? productId, required String userId}) Future<String>
resetMigrateTipState() Future<void>
restoreEntitlements({required String userId}) Future<List<Map<String, dynamic>>>
resumeSubscription({required String productId, required String userId}) Future<void>
setBaseUrlOverride(String? url) Future<void>
showManageSubscription({required String userId}) Future<void>
submitCancelFlowResponse(Map<String, dynamic> response) Future<void>
toString() String
A string representation of this object.
inherited
trackEvent({required String eventType, required String productId, String? screenName, Map<String, String>? metadata}) Future<void>
trackMigrationConversion({required String userId}) Future<void>
warmUpPaymentSheet({required String productId, String? userId}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ZeroSettlePlatform
getter/setter pair